@@ -1,6 +1,6 @@
-//$Id: app-res.h,v 1.10 2001/12/19 22:03:59 cactus Exp $ -*- c++ -*-
+//$Id: app-res.h,v 1.12 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -31,11 +31,15 @@ namespace Guikachu
 #include <sigc++/basic_signal.h>
 #include <string>
 
-#include "app-win.h"
 #include "resource.h"
 
 namespace Guikachu
 {
+    namespace GUI
+    {
+	class AppWindow; // Forward declaration
+    }
+    
     namespace Resources
     {
 	class Application: public SigC::Object
