@@ -1,4 +1,4 @@
-//$Id: checkbox.cc,v 1.19 2002/01/26 00:19:16 cactus Exp $ -*- c++ -*-
+//$Id: checkbox.cc,v 1.20 2002/03/15 17:47:08 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -27,7 +27,7 @@ using namespace Guikachu::GUI::FormEditor;
 Checkbox::Checkbox (Resources::Form   *owner,
 		    const std::string &id):
     Widget (owner, id),
-    Resizeable (changed),
+    ResizeableWidget (changed),
     AutoWidth (changed),
     AutoHeight (changed),
     Textual (changed, id),
