@@ -1,4 +1,4 @@
-//$Id: font.cc,v 1.9 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: font.cc,v 1.13 2002/01/12 14:12:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,6 +23,91 @@
 #include <stdio.h> /* For sscanf */
 #include <list>
 
+namespace {
+// Get next character from a string, with escape codes resolved
+static char next_char (const std::string &text,
+		       std::string::const_iterator &i)
+{
+    // Not an escape sequence
+    if (*i != '\\')
+	return *(i++);
+
+    // Trailing '\'
+    if (++i == text.end ())
+	return '\\';
+
+    // Check escape type
+    char escape_type = *i;
+
+    // Simple escape sequences
+    switch (escape_type)
+    {
+    case 'n':
+	i++;
+	return '\n';
+	break;
+    case 't':
+	i++;
+	return '\t';
+	break;
+    }
+
+#define IS_OCTAL(c)  ((c) >= '0' && (c) <= '7')
+#define GET_OCTAL(c) ((c) - '0')
+
+#define IS_HEX(c)  (((c) >= '0' && (c) <= '9') ||	\
+		    ((c) >= 'a' && (c) <= 'f') ||	\
+		    ((c) >= 'A' && (c) <= 'F'))
+
+#define GET_HEX(c) (((c) >= '0' && (c) <= '9') ?	\
+		     (c) - '0' :			\
+		     ((c) >= 'a' && (c) <= 'f') ?	\
+		      (c) - 'a' + 10 : (c) - 'A' + 10)
+    
+    
+    // Octal numbers
+    if (IS_OCTAL (escape_type))
+    {
+	char octal_value = 0;
+	
+	// Get next at most three octal numbers
+	for (int j = 0; j < 3 && i != text.end (); i++, j++)
+	{
+	    if (!IS_OCTAL (*i))
+		// Not an octal number
+		break;
+
+	    octal_value = octal_value * 8 + GET_OCTAL (*i);
+	}
+
+	return octal_value;
+    }
+
+    // Hexadecimal numbers
+    if (escape_type == 'x')
+    {
+	char hex_value = 0;
+
+	// Skip leading 0's
+	while (*(++i) == '0' && i != text.end ());
+	
+	// Read at most two hexadecimal characters
+	for (int j = 0; j < 2 && i != text.end (); i++, j++)
+	{
+	    if (!IS_HEX (*i))
+		break;
+
+	    hex_value = hex_value * 16 + GET_HEX (*i);
+	}
+
+	return hex_value;
+    }
+
+    // Unknown escape sequence: return escaped character
+    return *(i++);
+}
+}
+    
 using namespace Guikachu::GUI::FormEditor;
 
 Font::Font (const std::string &filename):
@@ -117,6 +202,16 @@ static void free_pixdata_delete (guchar *pixels, gpointer data)
     delete pixels;
 }
 
+const Glyph& Font::get_glyph (char c) const
+{
+    std::hash_map<char, Glyph>::const_iterator found_glyph = glyphs.find (c);
+    if (found_glyph != glyphs.end ())
+	return found_glyph->second;
+
+    static Glyph empty_glyph (height, ascent);
+
+    return empty_glyph;
+}
 
 GdkPixbuf* Font::render (const std::string &text,
 			 const Gdk_Color   &color) const
@@ -126,27 +221,45 @@ GdkPixbuf* Font::render (const std::string &text,
     
     std::list <Glyph> typeset;
     int width = 0;
-    
-    for (unsigned int i = 0; i < text.length (); i++)
-    {
-	std::hash_map<char, Glyph>::const_iterator curr_glyph_i = glyphs.find (text[i]);
-	
-	if (curr_glyph_i != glyphs.end ())
-        {
-            const Glyph& curr_glyph = curr_glyph_i->second;
-            typeset.push_back (curr_glyph);
 
-	    width += curr_glyph.width;
-        }
+    std::string::const_iterator i = text.begin ();
+    while (i != text.end ())
+    {
+	char c = next_char (text, i);
+	const Glyph &g = get_glyph (c);
+
+	typeset.push_back (g);
+	width += g.width;
     }
 
+#if 0
+    /* HACK: If there are no displayable characters, return a 
+     * blank1 x height pixmap
+     */
+    if (width == 0) 
+    {
+	guint32 *pixbuf_data = new guint32[height];
+	
+	for (unsigned int y = 0; y < height; y++)
+	    pixbuf_data[y] = 0;
+	
+	return gdk_pixbuf_new_from_data ((guchar *) pixbuf_data,
+					 GDK_COLORSPACE_RGB,
+					 true,
+					 8,
+					 1, height,
+					 4,
+					 free_pixdata_delete, 0);
+    }
+#endif
+    
     guchar *pixbuf_data = new guchar[width * height * 4];
     int x_position = 0;
 
     for (std::list<Glyph>::const_iterator i = typeset.begin ();
          i != typeset.end (); i++)
     {
-        const Glyph& glyph = *i;
+        const Glyph &glyph = *i;
 
         unsigned int curr_width = glyph.width;
         bool **curr_bitmap = glyph.bitmap;
@@ -187,12 +300,13 @@ unsigned int Font::string_width (const std::string &text) const
     
     int width = 0;
     
-    for (unsigned int i = 0; i < text.length (); i++)
+    std::string::const_iterator i = text.begin ();
+    while (i != text.end ())
     {
-	std::hash_map<char, Glyph>::const_iterator curr_glyph_i = glyphs.find (text[i]);
-	
-	if (curr_glyph_i != glyphs.end ())
-	    width += curr_glyph_i->second.width;
+	char c = next_char (text, i);
+	const Glyph &g = get_glyph (c);
+
+	width += g.width;
     }
 
     return width;
