@@ -1,4 +1,4 @@
-//$Id: form-canvas.h,v 1.2 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: form-canvas.h,v 1.3 2002/03/23 23:19:25 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,6 +32,7 @@ namespace Guikachu
 
 #include "form-res.h"
 #include "form-editor/canvasitem.h"
+#include "form-editor/resizeable-canvas.h"
 #include "form-editor/form.h"
 
 #include <gtk--/menu.h>
@@ -42,7 +43,7 @@ namespace Guikachu
     {
 	namespace FormEditor
 	{
-	    class FormCanvasItem: public CanvasItem
+	    class FormCanvasItem: public ResizeableCanvasItem
 	    {		
 		Resources::Form    *res;
 
@@ -81,6 +82,10 @@ namespace Guikachu
 		/* Callbacks */
 		void canvas_event_cb (GdkEvent *e);
 		void selected_cb     (bool selected);
+
+	    protected:
+		void get_bounds (int &x1, int &y1,
+				 int &x2, int &y2);
 	    };
 	}
     }
