@@ -1,6 +1,6 @@
-//$Id: form-prop.h,v 1.6 2001/04/14 18:01:40 cactus Exp $ -*- c++ -*-
+//$Id: form-prop.h,v 1.9 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -19,10 +19,21 @@
 #ifndef GUIKACHU_FORM_EDITOR_FORM_PROP_H
 #define GUIKACHU_FORM_EDITOR_FORM_PROP_H
 
+namespace Guikachu
+{
+    namespace GUI
+    {
+	namespace FormEditor
+	{
+	    class FormProperties;
+	}
+    }
+}
+
 #include "form-res.h"
 
 #include <string>
-#include <iostream>
+#include <gtk--/widget.h>
 
 namespace Guikachu
 {
