@@ -1,4 +1,4 @@
-//$Id: glyph.cc,v 1.3 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: glyph.cc,v 1.4 2002/01/12 14:12:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,6 +25,33 @@ using namespace Guikachu::GUI::FormEditor;
 #define GLYPH_ON  '#'
 #define GLYPH_OFF '-'
 
+Glyph::Glyph (unsigned int height, unsigned int ascent):
+    width (5),
+    bitmap (0)
+{
+    bitmap = new bool*[height];
+    
+    for (unsigned int i = 0; i < height; i++)
+    {
+	bitmap[i] = g_new0 (bool, width);
+    }
+
+    unsigned int y1 = ascent - 8;
+    unsigned int y2 = ascent - 1;
+
+    for (unsigned int x = 0; x < width; x++)
+    {
+	bitmap[y1][x] = true;
+	bitmap[y2][x] = true;
+    }
+
+    for (unsigned int y = y1; y < y2; y++)
+    {
+	bitmap[y][0] = true;
+	bitmap[y][4] = true;
+    }
+}
+
 Glyph::Glyph (std::istream &stream,
 	      unsigned int &height):
     width (0),
