@@ -1,4 +1,4 @@
-//$Id: graffiti-canvas.cc,v 1.9 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: graffiti-canvas.cc,v 1.11 2002/01/29 22:55:05 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -29,6 +29,7 @@ using namespace Guikachu::GUI::FormEditor;
 
 GraffitiCanvasItem::GraffitiCanvasItem (Widgets::Graffiti  *widget_,
 					Gnome::CanvasGroup *parent_group):
+    CanvasItem (widget_, parent_group),
     WidgetCanvasItem (widget_, parent_group),
     widget (widget_),
     group (0)
@@ -41,7 +42,7 @@ void GraffitiCanvasItem::update ()
     if (group)
 	delete group;
     
-    group = new Gnome::CanvasGroup (*parent_group, 0, 0);    
+    group = new Gnome::CanvasGroup (*draw_group, 0, 0);
     
     GdkPixbuf *pixbuf = gdk_pixbuf_new_from_xpm_data ((const char**)graffiti_canvas_xpm);
     gnome_canvas_item_new (group->gtkobj (),
