@@ -1,4 +1,4 @@
-//$Id: resizeable.cc,v 1.6 2002/01/30 17:33:10 cactus Exp $ -*- c++ -*-
+//$Id: resizeable.cc,v 1.8 2002/03/17 17:53:49 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,18 +22,11 @@
 
 using namespace Guikachu::Widgets;
 
-Resizeable::Resizeable (SigC::Signal0<void> &changed):
-    real_changed (changed),
-    width (width_changed, 0),
-    height (height_changed, 0)
+Resizeable::Resizeable (Property<int> &real_width,
+			Property<int> &real_height):
+    width (real_width),
+    height (real_height)
 {
-    width_changed.connect (SigC::slot (this, &Resizeable::emit_changed));
-    height_changed.connect (SigC::slot (this, &Resizeable::emit_changed));
-}
-
-void Resizeable::emit_changed ()
-{
-    real_changed.emit ();
 }
 
 int Resizeable::get_display_width  () const
