@@ -1,4 +1,4 @@
-//$Id: scrollbar.cc,v 1.16 2002/01/30 17:33:10 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar.cc,v 1.17 2002/03/15 17:47:09 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -29,7 +29,7 @@ using namespace Guikachu::GUI::FormEditor;
 ScrollBar::ScrollBar (Resources::Form   *owner,
 		      const std::string &id):
     Widget (owner, id),
-    Resizeable (changed),
+    ResizeableWidget (changed),
     AutoWidth (changed),
     
     editor (0),
