@@ -1,4 +1,4 @@
-//$Id: textual-prop.cc,v 1.5 2002/01/01 21:23:41 cactus Exp $ -*- c++ -*-
+//$Id: textual-prop.cc,v 1.6 2002/01/05 23:35:20 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,7 +22,7 @@
 #include <libgnome/libgnome.h>
 
 #include "widgets/entry.h"
-#include "widgets/num-entry.h"
+#include "widgets/font-combo.h"
 
 using namespace Guikachu::GUI::FormEditor;
 
@@ -36,6 +36,6 @@ void TextualProperties::add_controls (Widgets::Textual   *res,
     proptable.add (_("_Text:"), *manage (control));
 
     /* Font */
-    control = new GUI::PropertyEditors::NumEntry (0, 2, res->font);
+    control = new GUI::PropertyEditors::FontCombo (res->font);
     proptable.add (_("_Font:"), *manage (control));
 }
