@@ -1,4 +1,4 @@
-//$Id: main.cc,v 1.17 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: main.cc,v 1.18 2002/01/09 17:26:41 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -108,6 +108,11 @@ static bool check_files ()
 	{"stdfont.txt",          FILETYPE_FONT},
 	{"boldfont.txt",         FILETYPE_FONT},
 	{"bigfont.txt",          FILETYPE_FONT},
+        {"symbol.txt",    FILETYPE_FONT},
+        {"symbol11.txt",    FILETYPE_FONT},
+        {"symbol7.txt",    FILETYPE_FONT},
+        {"ledfont.txt",    FILETYPE_FONT},
+        {"bigbold.txt",    FILETYPE_FONT},
 	{"palm.guikachu-target", FILETYPE_TARGET_DEF}
     };
 
