@@ -1,4 +1,4 @@
-//$Id: menu-res.h,v 1.10 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: menu-res.h,v 1.11 2002/01/04 17:34:28 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,8 +23,6 @@ namespace Guikachu
 {
     namespace Resources
     {
-	struct MenuItem;
-	struct Submenu;
 	class Menu;
     }
 }
@@ -42,25 +40,27 @@ namespace Guikachu
     
     namespace Resources
     {
-	struct MenuItem
-	{
-	    bool        separator;
-	    std::string id;
-	    std::string label;
-	    char        shortcut;
-	};
-
-	struct Submenu
-	{
-	    std::string           label;
-	    std::vector<MenuItem> items;
-
-	    Submenu () {};
-	    Submenu (const std::string& label_): label (label_) {};
-	};
-	
 	class Menu: public Resource
 	{
+	public:
+	    struct MenuItem
+	    {
+		bool        separator;
+		std::string id;
+		std::string label;
+		char        shortcut;
+	    };
+	    
+	    struct Submenu
+	    {
+		std::string           label;
+		std::vector<MenuItem> items;
+		
+		Submenu () {};
+		Submenu (const std::string& label_): label (label_) {};
+	    };
+	    
+	private:
 	    typedef std::vector<Submenu> MenuTree;
 	    
 	    Guikachu::GUI::MenuWindow *gui;
