@@ -1,4 +1,4 @@
-//$Id: preferences.cc,v 1.6 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: preferences.cc,v 1.7 2002/04/18 15:23:42 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -62,7 +62,7 @@ void Preferences::load ()
 #define GET_COLOR(color) gconf_client_get_string (gconf_client, GCONF_ROOT "/FormEditor/Colors/" color, 0)
 
     FormEditor::color_fg = GET_COLOR ("foreground");
-    FormEditor::color_disabled = GET_COLOR ("foreground-disabled");
+    FormEditor::color_disabled = GET_COLOR ("foreground_disabled");
     FormEditor::color_bg = GET_COLOR ("background");
     FormEditor::color_selection = GET_COLOR ("selection");    
     
@@ -74,7 +74,7 @@ void Preferences::load ()
     gconf_client_notify_add(gconf_client, GCONF_ROOT "/FormEditor/Colors/foreground",
 			    FormEditor::gconf_color_cb,
 			    &FormEditor::color_fg, 0, 0);
-    gconf_client_notify_add(gconf_client, GCONF_ROOT "/FormEditor/Colors/foreground-disabled",
+    gconf_client_notify_add(gconf_client, GCONF_ROOT "/FormEditor/Colors/foreground_disabled",
 			    FormEditor::gconf_color_cb,
 			    &FormEditor::color_disabled, 0, 0);
     gconf_client_notify_add(gconf_client, GCONF_ROOT "/FormEditor/Colors/background",
@@ -100,7 +100,7 @@ void Preferences::FormEditor::set_colors (const std::string &color_fg_,
 #define SET_COLOR(key,value) if (value##_ != value) gconf_client_set_string (gconf_client, GCONF_ROOT "/FormEditor/Colors/" key, value##_.c_str (), 0)
 
     SET_COLOR("foreground", color_fg);
-    SET_COLOR("foreground-disabled", color_disabled);
+    SET_COLOR("foreground_disabled", color_disabled);
     SET_COLOR("background", color_bg);
     SET_COLOR("selection", color_selection);
 
