@@ -1,4 +1,4 @@
-//$Id: target.cc,v 1.4 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: target.cc,v 1.5 2002/01/08 23:27:07 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -167,12 +167,16 @@ StockTargetData load_stock_data (const std::string &stock_id)
 		   filename.c_str ());
 	return StockTargetData (description, screen_width, screen_height);
     }
+
+    // Load translated entries first
+    description = root_node.get_translated_child ("description").get_content ();
     
     for (StorageNode curr_node = root_node.children ();
 	 curr_node; curr_node++)
     {
 	if (curr_node.name () == "description")
-	    description = curr_node.get_content ();
+	    // Already loaded -- mentioned here only to surpass waning
+	    ;
 	else if (curr_node.name () == "screen")
 	{
 	    screen_width  = curr_node.get_prop<int> ("width");
